==> jc-1.4.0.tar.gz: soot/util/queue/QueueReader.h <==
// public class soot.util.queue.QueueReader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dfc99826de09e7ed soot_util_queue_QueueReader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_queue_QueueReader_H_
#define _JC_soot_util_queue_QueueReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_queue_QueueReader$sub_refs	_jc_soot_util_queue_QueueReader$sub_refs;
typedef struct _jc_soot_util_queue_QueueReader$sub_nonrefs	_jc_soot_util_queue_QueueReader$sub_nonrefs;
typedef struct _jc_soot_util_queue_QueueReader$refs	_jc_soot_util_queue_QueueReader$refs;
typedef struct _jc_soot_util_queue_QueueReader$nonrefs	_jc_soot_util_queue_QueueReader$nonrefs;
typedef struct _jc_soot_util_queue_QueueReader$object	_jc_soot_util_queue_QueueReader$object;

typedef const struct _jc_soot_util_queue_QueueReader$vmethods	_jc_soot_util_queue_QueueReader$vmethods;
typedef const struct _jc_soot_util_queue_QueueReader$vtable	_jc_soot_util_queue_QueueReader$vtable;
typedef const struct _jc_soot_util_queue_QueueReader$vtype	_jc_soot_util_queue_QueueReader$vtype;

// Constructors
extern void _jc_soot_util_queue_QueueReader$method$_init$154a766f8ebd690f(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *, struct _jc_object_array *, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_queue_QueueReader$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
extern jboolean _jc_soot_util_queue_QueueReader$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_util_queue_QueueReader$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
extern void _jc_soot_util_queue_QueueReader$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_queue_QueueReader$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *);
};

// Vtable
struct _jc_soot_util_queue_QueueReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_queue_QueueReader$vmethods	soot_util_queue_QueueReader;
};

// Vtype
struct _jc_soot_util_queue_QueueReader$vtype {
	_jc_type			type;
	_jc_soot_util_queue_QueueReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_queue_QueueReader$sub_refs {
	_jc_object_array	*q;
};

// Reference instance fields (object)
struct _jc_soot_util_queue_QueueReader$refs {
    _jc_soot_util_queue_QueueReader$sub_refs	soot_util_queue_QueueReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_queue_QueueReader$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_util_queue_QueueReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_queue_QueueReader$sub_nonrefs	soot_util_queue_QueueReader;
};

// Object instance structure
struct _jc_soot_util_queue_QueueReader$object {
	_jc_soot_util_queue_QueueReader$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_queue_QueueReader$vtype	*vtype;
	_jc_soot_util_queue_QueueReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_queue_QueueReader$vtype _jc_soot_util_queue_QueueReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_queue_QueueReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_queue_QueueReader$class_object;

#endif	/* _JC_soot_util_queue_QueueReader_H_ */

==> jc-1.4.6.tar.gz: soot/util/queue/QueueReader.h <==
// public class soot.util.queue.QueueReader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dfc99826de09e7ed soot_util_queue_QueueReader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_queue_QueueReader_H_
#define _JC_soot_util_queue_QueueReader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_util_queue_QueueReader$sub_refs	_jc_soot_util_queue_QueueReader$sub_refs;
typedef struct _jc_soot_util_queue_QueueReader$sub_nonrefs	_jc_soot_util_queue_QueueReader$sub_nonrefs;
typedef struct _jc_soot_util_queue_QueueReader$refs	_jc_soot_util_queue_QueueReader$refs;
typedef struct _jc_soot_util_queue_QueueReader$nonrefs	_jc_soot_util_queue_QueueReader$nonrefs;
typedef struct _jc_soot_util_queue_QueueReader$object	_jc_soot_util_queue_QueueReader$object;

typedef const struct _jc_soot_util_queue_QueueReader$vmethods	_jc_soot_util_queue_QueueReader$vmethods;
typedef const struct _jc_soot_util_queue_QueueReader$vtable	_jc_soot_util_queue_QueueReader$vtable;
typedef const struct _jc_soot_util_queue_QueueReader$vtype	_jc_soot_util_queue_QueueReader$vtype;

// Constructors
extern void _jc_soot_util_queue_QueueReader$method$_init$154a766f8ebd690f(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_util_queue_QueueReader$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_util_queue_QueueReader$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_util_queue_QueueReader$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
extern void _jc_soot_util_queue_QueueReader$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_util_queue_QueueReader$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_util_queue_QueueReader$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_util_queue_QueueReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_queue_QueueReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_queue_QueueReader$vmethods	soot_util_queue_QueueReader;
};

// Vtype
struct _jc_soot_util_queue_QueueReader$vtype {
	_jc_type			type;
	_jc_soot_util_queue_QueueReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_queue_QueueReader$sub_refs {
	_jc_object_array	*q;
};

// Reference instance fields (object)
struct _jc_soot_util_queue_QueueReader$refs {
    _jc_soot_util_queue_QueueReader$sub_refs	soot_util_queue_QueueReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_queue_QueueReader$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_soot_util_queue_QueueReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_queue_QueueReader$sub_nonrefs	soot_util_queue_QueueReader;
};

// Object instance structure
struct _jc_soot_util_queue_QueueReader$object {
	_jc_soot_util_queue_QueueReader$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_queue_QueueReader$vtype	*vtype;
	_jc_soot_util_queue_QueueReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_queue_QueueReader$vtype _jc_soot_util_queue_QueueReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_queue_QueueReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_queue_QueueReader$class_object;

#endif	/* _JC_soot_util_queue_QueueReader_H_ */
